<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
  outlineTree.xlst
  Copyright  2006-2008 Kinook Software, Inc.
  http://www.ultrarecall.com/

  Converts Ultra Recall XML export to an HTML collapsible outline, including the item title and text.

  Javascript tree code is based on: http://www.javascripttoolbox.com/lib/mktree/index.php

  See http://www.kinook.com/Forum/showthread.php?threadid=2104 for details.

-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html" encoding="UTF-8" indent="yes" />
	<xsl:param name="numbering">yes</xsl:param>

	<xsl:template match="/oml/body">

		<!-- boilerplate HTML for page -->
		<html>
		<head>
			<SCRIPT LANGUAGE="JavaScript" SRC="mktree.js" />
			<LINK REL="stylesheet" HREF="mktree.css" />
		</head>
		<body>
			<ul class="mktree" id="tree1">

				<!-- process outline nodes -->
				<xsl:apply-templates select="outline" />

			</ul>
		</body>
		</html>

	</xsl:template>

	<xsl:template match="outline">

		<br/><li class="liOpen">
			
			<b>

			<!-- add item number if enabled -->
			<xsl:if test="$numbering='yes'">
				<!-- format value below can use the following values:
				  1 => 1, 2, 3, 4, ...
				  a => a, b, c, d, ... x, y, z, aa, ab, ac, ...
				  A => A, B, C, D, ... X, Y, Z, AA, AB, AC, ...
				  i => i, ii, iii, iv, ... x, xi, xii, xiii, xiv, ...
				  I => I, II, III, IV, ... X, XI, XII, XIII, XIV, ...

				  multiple values between periods can be used to vary the formatting
				  per level (i.e., "1.a.A.i.I").
				-->
				<xsl:number level="multiple" count="outline" format="1" />: 
			</xsl:if>

			<xsl:value-of select="@text" />

			</b>

			<!-- include item text if there is some -->
			<xsl:if test="Item[@name='Item Text']">

				<br/><table border="0" cellpadding="0" cellspacing="0">
					<tr valign="center">
						<td align="right" width="30"></td>
						<td align="left">
							<xsl:call-template name="break">
								<xsl:with-param name="text" select="Item[@name='Item Text']" />
							</xsl:call-template>
						</td>
					</tr>
				</table>

			</xsl:if>

			<!-- include item text if there is some -->
			<xsl:if test="outline">

				<ul>

				<!-- recursively process outline nodes -->
				<xsl:apply-templates select="outline" />

				</ul>

			</xsl:if>

		</li>

	</xsl:template>

	<!-- convert newlines in text to HTML br elements -->
	<xsl:template name="break">
		<xsl:param name="text" select="." />
		<xsl:choose>
			<xsl:when test="contains($text, '&#xa;')">
				<xsl:value-of select="substring-before($text, '&#xa;')" /><br />
				<xsl:call-template name="break">
					<xsl:with-param name="text" select="substring-after($text, '&#xa;')" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
